==> jc-1.4.0.tar.gz: java/lang/annotation/AnnotationFormatError.h <==
// public class java.lang.annotation.AnnotationFormatError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class e6c98c182947dc55 java_lang_annotation_AnnotationFormatError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_lang_annotation_AnnotationFormatError_H_
#define _JC_java_lang_annotation_AnnotationFormatError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_annotation_AnnotationFormatError$sub_refs	_jc_java_lang_annotation_AnnotationFormatError$sub_refs;
typedef struct _jc_java_lang_annotation_AnnotationFormatError$sub_nonrefs	_jc_java_lang_annotation_AnnotationFormatError$sub_nonrefs;
typedef struct _jc_java_lang_annotation_AnnotationFormatError$refs	_jc_java_lang_annotation_AnnotationFormatError$refs;
typedef struct _jc_java_lang_annotation_AnnotationFormatError$nonrefs	_jc_java_lang_annotation_AnnotationFormatError$nonrefs;
typedef struct _jc_java_lang_annotation_AnnotationFormatError$object	_jc_java_lang_annotation_AnnotationFormatError$object;

typedef const struct _jc_java_lang_annotation_AnnotationFormatError$vmethods	_jc_java_lang_annotation_AnnotationFormatError$vmethods;
typedef const struct _jc_java_lang_annotation_AnnotationFormatError$vtable	_jc_java_lang_annotation_AnnotationFormatError$vtable;
typedef const struct _jc_java_lang_annotation_AnnotationFormatError$vtype	_jc_java_lang_annotation_AnnotationFormatError$vtype;

// Constructors
extern void _jc_java_lang_annotation_AnnotationFormatError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_annotation_AnnotationFormatError$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_lang_annotation_AnnotationFormatError$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_lang_annotation_AnnotationFormatError$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_java_lang_annotation_AnnotationFormatError$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_annotation_AnnotationFormatError$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_java_lang_annotation_AnnotationFormatError$vmethods {
};

// Vtable
struct _jc_java_lang_annotation_AnnotationFormatError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_annotation_AnnotationFormatError$vmethods	java_lang_annotation_AnnotationFormatError;
};

// Vtype
struct _jc_java_lang_annotation_AnnotationFormatError$vtype {
	_jc_type			type;
	_jc_java_lang_annotation_AnnotationFormatError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_annotation_AnnotationFormatError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_annotation_AnnotationFormatError$refs {
    _jc_java_lang_annotation_AnnotationFormatError$sub_refs	java_lang_annotation_AnnotationFormatError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_annotation_AnnotationFormatError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_annotation_AnnotationFormatError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_annotation_AnnotationFormatError$sub_nonrefs	java_lang_annotation_AnnotationFormatError;
};

// Object instance structure
struct _jc_java_lang_annotation_AnnotationFormatError$object {
	_jc_java_lang_annotation_AnnotationFormatError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_annotation_AnnotationFormatError$vtype	*vtype;
	_jc_java_lang_annotation_AnnotationFormatError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_annotation_AnnotationFormatError$vtype _jc_java_lang_annotation_AnnotationFormatError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_annotation_AnnotationFormatError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_annotation_AnnotationFormatError$class_object;

#endif	/* _JC_java_lang_annotation_AnnotationFormatError_H_ */

==> jc-1.4.6.tar.gz: java/lang/annotation/AnnotationFormatError.h <==
// public class java.lang.annotation.AnnotationFormatError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class e6c98c182947dc55 java_lang_annotation_AnnotationFormatError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_lang_annotation_AnnotationFormatError_H_
#define _JC_java_lang_annotation_AnnotationFormatError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_annotation_AnnotationFormatError$sub_refs	_jc_java_lang_annotation_AnnotationFormatError$sub_refs;
typedef struct _jc_java_lang_annotation_AnnotationFormatError$sub_nonrefs	_jc_java_lang_annotation_AnnotationFormatError$sub_nonrefs;
typedef struct _jc_java_lang_annotation_AnnotationFormatError$refs	_jc_java_lang_annotation_AnnotationFormatError$refs;
typedef struct _jc_java_lang_annotation_AnnotationFormatError$nonrefs	_jc_java_lang_annotation_AnnotationFormatError$nonrefs;
typedef struct _jc_java_lang_annotation_AnnotationFormatError$object	_jc_java_lang_annotation_AnnotationFormatError$object;

typedef const struct _jc_java_lang_annotation_AnnotationFormatError$vmethods	_jc_java_lang_annotation_AnnotationFormatError$vmethods;
typedef const struct _jc_java_lang_annotation_AnnotationFormatError$vtable	_jc_java_lang_annotation_AnnotationFormatError$vtable;
typedef const struct _jc_java_lang_annotation_AnnotationFormatError$vtype	_jc_java_lang_annotation_AnnotationFormatError$vtype;

// Constructors
extern void _jc_java_lang_annotation_AnnotationFormatError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_annotation_AnnotationFormatError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_annotation_AnnotationFormatError$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_lang_annotation_AnnotationFormatError$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_annotation_AnnotationFormatError$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_annotation_AnnotationFormatError$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_annotation_AnnotationFormatError$vmethods {
};

// Vtable
struct _jc_java_lang_annotation_AnnotationFormatError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_annotation_AnnotationFormatError$vmethods	java_lang_annotation_AnnotationFormatError;
};

// Vtype
struct _jc_java_lang_annotation_AnnotationFormatError$vtype {
	_jc_type			type;
	_jc_java_lang_annotation_AnnotationFormatError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_annotation_AnnotationFormatError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_annotation_AnnotationFormatError$refs {
    _jc_java_lang_annotation_AnnotationFormatError$sub_refs	java_lang_annotation_AnnotationFormatError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_annotation_AnnotationFormatError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_annotation_AnnotationFormatError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_annotation_AnnotationFormatError$sub_nonrefs	java_lang_annotation_AnnotationFormatError;
};

// Object instance structure
struct _jc_java_lang_annotation_AnnotationFormatError$object {
	_jc_java_lang_annotation_AnnotationFormatError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_annotation_AnnotationFormatError$vtype	*vtype;
	_jc_java_lang_annotation_AnnotationFormatError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_annotation_AnnotationFormatError$vtype _jc_java_lang_annotation_AnnotationFormatError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_annotation_AnnotationFormatError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_annotation_AnnotationFormatError$class_object;

#endif	/* _JC_java_lang_annotation_AnnotationFormatError_H_ */
